# PyPackIT-Test1 © 2024 Armin Ariamajd
# SPDX-License-Identifier: MIT

"""PyPackIT Test1: A New Python Project.

Welcome to PyPackIT Test1 powered by <a href="https://pypackit.repodynamics.com/">PyPackIT</a>.
Replace this text with a short abstract of PyPackIT Test1, describing its purpose and main features.
By default, this text is displayed on the repository's main README file, on the homepage of the
project's website, on the project's PyPI and TestPyPI pages, and on the package's main docstring.
Like all other entries in the repository's control center, this text can also contain dynamic
references to other entries, using the <code>${‎{ json-path.to.value }}$</code> syntax. By default,
the first occurrence of the name of the project in this text is styled as strong and linked to the
project's website.
"""

from pypackit_test1 import data

__all__ = ["data", "__version_details__", "__version__"]

__version_details__: dict[str, str] = { "version": "0.0.8", "build_date": "2024.11.18", "committer_date": "2024.11.18", "author_date": "2024.11.18", "branch": "main", "distance": "0", "commit_hash": "422ed227cae6e2a7d0e9e1775a575e30ca44f2ee" }
"""Details of the currently installed version of the package,
including version number, date, branch, and commit hash."""

__version__: str = __version_details__["version"]
"""Version number of the currently installed package."""



# PyPackIT-Test1 © 2024 Armin Ariamajd
# SPDX-License-Identifier: MIT

"""Main command-line interface of the package."""

import argparse
import sys

from pypackit_test1 import __version__


def main() -> int:
    """Run the main command-line interface of the package."""
    # AUTOCODE START: cli
    cli_description: str = "Command-line interface for the package."
    cli_greeting: str = "Welcome to the package's command-line interface!"
    cli_logo: str = ""
    # AUTOCODE END: cli

    parser = argparse.ArgumentParser(description=cli_description)
    parser.add_argument(
        "--version",
        action="version",
        version=f"%(prog)s {__version__}",
        help="Show the current version of the package.",
    )
    args = parser.parse_args()
    if not vars(args):
        if cli_logo:
            print(cli_logo)
        print(cli_greeting)
    return 0


if __name__ == "__main__":
    sys.exit(main())



# PyPackIT-Test1 © 2024 Armin Ariamajd
# SPDX-License-Identifier: MIT

"""Functions for retrieving package data files."""

from __future__ import annotations as _annotations

from pathlib import Path as _Path

import pkgdata as _pkgdata

__all__ = ["filepath"]


def filepath(relative_path: str) -> _Path:
    """Get the absolute path to a package data file.

    Parameters
    ----------
    relative_path
        Path to the file relative to the package's data directory.
    """
    path_data_dir = _Path(_pkgdata.get_package_path_from_caller(top_level=False))
    abs_filepath = path_data_dir / relative_path
    if not abs_filepath.is_file():
        from pypackit_test1.exception.data import DataFileNotFoundError

        raise DataFileNotFoundError(
            path_relative=relative_path,
            path_absolute=abs_filepath,
        )
    return abs_filepath



# PyPackIT-Test1 © 2024 Armin Ariamajd
# SPDX-License-Identifier: MIT

"""Exceptions raised by the data module."""

from __future__ import annotations as _annotations

from typing import TYPE_CHECKING as _TYPE_CHECKING

from pypackit_test1.exception import PackageError as _PackageError

if _TYPE_CHECKING:
    from pathlib import Path


class DataFileNotFoundError(_PackageError):
    """Raised when a requested package data file is not found.

    Parameters
    ----------
    path_relative
        Path to the file relative to the package's data directory.
    path_absolute
        Absolute path to the file.
    """

    def __init__(
        self,
        path_relative: str,
        path_absolute: Path,
    ):
        self.path_relative = path_relative
        self.path_absolute = path_absolute
        super().__init__(
            "Could not find the requested package data file "
            f"'{path_relative}' at '{path_absolute}'.",
        )
        return



# PyPackIT-Test1 © 2024 Armin Ariamajd
# SPDX-License-Identifier: MIT

"""Exceptions raised by the package."""


class PackageError(Exception):
    """Base class for all exceptions raised by this package."""
